BioData <- function(rawBio, Level){
  D.rawBio <- as.matrix(rawBio)                          # matrix
  AB.MAT   <- data.frame(rawBio[,8:(ncol(rawBio))])      # Abundance in samplers for the raw data

  ## Extraction of the names in analysis level
  D.level           <- matrix("NA", nrow = nrow(rawBio), ncol = 5)
  D.level[1,1:5]    <- as.matrix(rawBio)[1,1:5]
  colnames(D.level) <- c("Type", "Phylum", "Class", "Order", "Family")
  ic <- 2
  for(i in 2:nrow(rawBio)){
    if(any(D.level[,Level]==D.rawBio[i,Level])){
      D.level[,1:5] <- D.level[,1:5]
    }else{
      D.level[ic,1:5] <- D.rawBio[i,1:5]
      ic <- ic + 1
    }
  }
  D.level <- subset(D.level, D.level[,1]!="NA")

  ## Data arrangement for the analysis of taxonomic levels
  ABS.ANAL <- data.frame(matrix(0, nrow = nrow(D.level), ncol = ncol(rawBio)-7))
  for(i1 in 1:nrow(D.level)){
    for(i2 in 1:nrow(rawBio)){
      if(D.rawBio[i2,Level]==D.level[i1,Level]){
        ABS.ANAL[i1,1:(ncol(rawBio)-7)] <-               # Abundance in samplers for the analysis level
          ABS.ANAL[i1,1:(ncol(rawBio)-7)] + as.integer(AB.MAT[i2,1:(ncol(rawBio)-7)])
      }
    }
  }

  INC.ANAL <- ifelse(ABS.ANAL!=0, 1, 0)                  # Incidence for the analysis level

  rownames(ABS.ANAL)  <- D.level[,Level]
  rownames(INC.ANAL)  <- D.level[,Level]
  colnames(ABS.ANAL)  <- colnames(rawBio[,8:ncol(rawBio)])
  colnames(INC.ANAL)  <- colnames(rawBio[,8:ncol(rawBio)])


  ## Data arrangement for the analysis of analysis level structures based on the Family level
  # Extraction of the names in the family level
  Fa.level           <- matrix("NA", nrow = nrow(rawBio), ncol = 5)
  Fa.level[1,1:5]    <- as.matrix(rawBio)[1,1:5]
  colnames(Fa.level) <- c("Type", "Phylum", "Class", "Order", "Family")
  ic <- 2
  for(i in 2:nrow(rawBio)){
    if(any(Fa.level[,"Family"]==D.rawBio[i,"Family"])){
      Fa.level[,1:5] <- Fa.level[,1:5]
    }else{
      Fa.level[ic,1:5] <- D.rawBio[i,1:5]
      ic <- ic + 1
    }
  }
  Fa.level <- subset(Fa.level, Fa.level[,1]!="NA")

  # Producing an incidence matrix for Family level
  PA.MAT <- data.frame(matrix(0, nrow = nrow(Fa.level), ncol = ncol(rawBio)-7))
  for(i1 in 1:nrow(Fa.level)){
    for(i2 in 1:nrow(rawBio)){
      if(D.rawBio[i2,"Family"]==Fa.level[i1,"Family"]){
        PA.MAT[i1,1:(ncol(rawBio)-7)] <-
          PA.MAT[i1,1:(ncol(rawBio)-7)] + as.integer(AB.MAT[i2,1:(ncol(rawBio)-7)])
      }
    }
  }
  PA.MAT <- ifelse(PA.MAT!=0, 1, 0)
  rownames(PA.MAT) <- Fa.level[,"Family"]

  # Producing an abundance in the unit area matrix for Family level
  ABA.ANAL <- data.frame(matrix(0, nrow = nrow(D.level), ncol = ncol(rawBio)-7))
  for(i in 1:nrow(ABS.ANAL)){
    ABA.ANAL[i,1:ncol(ABS.ANAL)] <-                      # Abundance in unit areas for the analysis taxon level
      ABS.ANAL[i,1:ncol(ABS.ANAL)]/
      t(rawChem$Size[1:ncol(ABS.ANAL)])/t(rawChem$No_sampling[1:ncol(ABS.ANAL)])
  }
  rownames(ABA.ANAL) <- D.level[,Level]
  colnames(ABA.ANAL) <- colnames(rawBio[,8:ncol(rawBio)])

  # Counting the number of families in analysis levels
  NF.ANAL  <- data.frame(matrix(0, nrow = nrow(D.level), ncol = ncol(rawBio)-7))
  TNF.sum  <- data.frame(matrix(0, nrow = nrow(D.level), ncol = 1))
  rownames(NF.ANAL) <- D.level[,Level]
  rownames(TNF.sum) <- D.level[,Level]
  colnames(NF.ANAL) <- colnames(rawBio[,8:ncol(rawBio)])
  for(i in 1:nrow(Fa.level)){
    NF.ANAL[Fa.level[i,Level],]  <-      # No. of families matrix
      NF.ANAL[Fa.level[i,Level],] + PA.MAT[i,]
  
    if(sum(PA.MAT[i,])!=0){
      TNF.sum[Fa.level[i,Level],1] <-    # Total number of families in analysis level
        TNF.sum[Fa.level[i,Level],1] + 1
    }
  }

  return(list(D.level=D.level,
              INC.ANAL=INC.ANAL,
              ABS.ANAL=ABS.ANAL,
              ABA.ANAL=ABA.ANAL,
              NF.ANAL=NF.ANAL,
              TNF.sum=TNF.sum))
}