### Preprocessing ###
## Input an analysis level
Level   <- "Family"                                    # Phylum, Class, Order, Family


## Read data
rawBio   <- read.csv("Bio.csv", header = TRUE)         # list
rawChem  <- read.csv("Chem.csv", header = TRUE)        # list


## Biological Data
source("BioData.R")
BR <- BioData(rawBio, Level)

D.level  <- BR$D.level
INC.ANAL <- BR$INC.ANAL
ABS.ANAL <- BR$ABS.ANAL
ABA.ANAL <- BR$ABA.ANAL
NF.ANAL  <- BR$NF.ANAL
TNF.sum  <- BR$TNF.sum


## Environmental Data
Chem1.ANAL <- rawChem[, 7:ncol(rawChem)]
rownames(Chem1.ANAL) <- rawChem$Site

Sampling       <- rawChem$Size*rawChem$No_sampling
Chem2.ANAL     <- cbind(Sampling, Chem1.ANAL)



### Analysing -Similarity anaysis- ###
library(vegan)

## Presence or Abusence base multivariate analysis
INC1.ANAL  <- t(INC.ANAL)
ABS1.ANAL  <- t(ABS.ANAL)
Chem1.ANAL <- subset(Chem1.ANAL, rowSums(INC1.ANAL)!=0)
Chem2.ANAL <- subset(Chem2.ANAL, rowSums(INC1.ANAL)!=0)
INC1.ANAL  <- subset(INC1.ANAL, rowSums(INC1.ANAL)!=0)
ABS1.ANAL  <- subset(ABS1.ANAL, rowSums(ABS1.ANAL)!=0)
ord111      <- metaMDS(INC1.ANAL, distance = "jaccard", k = 2)
ord112      <- metaMDS(ABS1.ANAL, distance = "chao", k = 2)
ord113      <- metaMDS(ABS1.ANAL, distance = "bray", k = 2)
dbrda111    <- capscale(INC1.ANAL ~ 1, distance = "jaccard")                      # PCoA
dbrda112    <- capscale(INC1.ANAL ~ .,Chem1.ANAL, distance = "jaccard")           # dbRDA
dbrda121    <- capscale(ABS1.ANAL ~ 1, distance = "chao")                         # PCoA
dbrda122    <- capscale(ABS1.ANAL ~ .,Chem1.ANAL, distance = "chao")              # dbRDA
dbrda131    <- capscale(ABS1.ANAL ~ 1, distance = "bray")                         # PCoA
dbrda132    <- capscale(ABS1.ANAL ~ .,Chem1.ANAL, distance = "bray")              # dbRDA

permtest    <- adonis(ABS1.ANAL ~ .,Chem1.ANAL, permutations = 10000, method = "chao")                  # Permutation ANOVA

## Number of families base multivariate analysis
NF1.ANAL   <- t(NF.ANAL)
NF1.ANAL   <- subset(NF1.ANAL,  rowSums(NF1.ANAL)!=0)
ord211     <- metaMDS(NF1.ANAL,  distance = "bray", k = 2)
dbrda211   <- capscale(NF1.ANAL ~ 1, distance = "bray")                          # PCoA
dbrda212   <- capscale(NF1.ANAL ~ .,Chem2.ANAL, distance = "bray")               # dbRDA


### Output -Common- ###
write.table(subset(ABA.ANAL,rowSums(ABA.ANAL)!=0), file = "Abundance.csv", sep=",")
write.table(subset(INC.ANAL,rowSums(INC.ANAL)!=0), file = "Incidence.csv", sep=",")
write.table(TNF.sum,  file = "Total_No_of_families.csv", sep=",")
write.table(NF.ANAL,  file = "No_of_families.csv", sep=",")
write.table(as.matrix(vegdist(INC1.ANAL, method="jaccard")), file = "Jaccard_distance.csv", sep=",")
write.table(as.matrix(vegdist(ABS1.ANAL, method="chao")), file = "Chao_distance.csv", sep=",")
write.table(as.matrix(vegdist(ABS1.ANAL, method="bray")), file = "BC_distance.csv", sep=",")


### Output -Similarity- ###
sink("PA_assemblage.txt")
  print(ord111)
  print(ord111$points)
  print(ord111$species)
  summary(dbrda111)
  summary(dbrda112)

  print(ord112)
  print(ord112$points)
  print(ord112$species)
  summary(dbrda121)
  summary(dbrda122)

  print(ord113)
  print(ord113$points)
  print(ord113$species)
  summary(dbrda131)
  summary(dbrda132)
sink()

sink("PA_assemblage-test.txt")
  print(permtest)
  summary(dbrda122)
sink()

sink("NF_assemblage.txt")
  print(ord211)
  print(ord211$points)
  print(ord211$species)
  summary(dbrda211)
  summary(dbrda212)
sink()



### Figures ###
plot(ord12,   type = 't')       # nMDS, P/A families, Chao
plot(ord21,   type = 't')       # nMDS, number of families, Bray-Curtis
plot(dbrda12, type = 't')       # RDA, P/A families, Jaccard
plot(dbrda22, type = 't')       # RDA, P/A families, Chao
plot(dbrda32, type = 't')       # RDA, number of families, Chao
